aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--build/generate-sri.js4
-rw-r--r--hugo.yml (renamed from config.yml)0
2 files changed, 2 insertions, 2 deletions
diff --git a/config.yml b/hugo.yml
index fe3d9e86c..fe3d9e86c 100644
--- a/config.yml
+++ b/hugo.yml
diff --git a/build/generate-sri.js b/build/generate-sri.js
index 1674247a8..2e2292475 100644
--- a/build/generate-sri.js
+++ b/build/generate-sri.js
@@ -18,11 +18,11 @@ const sh = require('shelljs')
sh.config.fatal = true
-const configFile = path.join(__dirname, '../config.yml')
+const configFile = path.join(__dirname, '../hugo.yml')
// Array of objects which holds the files to generate SRI hashes for.
// `file` is the path from the root folder
// `configPropertyName` is the config.yml variable's name of the file
const files = [
{
file: 'dist/css/bootstrap.min.css',
@@ -18,11 +18,11 @@ const sh = require('shelljs')
// Array of objects which holds the files to generate SRI hashes for.
// `file` is the path from the root folder
-// `configPropertyName` is the config.yml variable's name of the file
+// `configPropertyName` is the hugo.yml variable's name of the file
const files = [
{